@@ -46,7 +46,7 @@ int main(int argc, char** argv)
     lowerSchedulingPriority();
     lowerPriority();
 
-    KAboutData aboutData(QLatin1String("baloo_file"), i18n("Baloo File"), QLatin1String("0.1"),
+    KAboutData aboutData(QLatin1String("baloo_file"), i18n("Baloo File"), PROJECT_VERSION,
                          i18n("An application to handle file metadata"),
                          KAboutLicense::LGPL_V2);
     aboutData.addAuthor(i18n("Vishesh Handa"), i18n("Maintainer"), QLatin1String("me@vhanda.in"), QLatin1String("http://vhanda.in"));
@@ -82,12 +82,6 @@ int main(int argc, char** argv)
     KCrash::setFlags(KCrash::AutoRestart);
 
     const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/baloo/file/");
-    QFileInfo dirInfo(path);
-    if (!dirInfo.permission(QFile::WriteOwner)) {
-        QTextStream err(stderr);
-        err << path << " does not have write permissions. Aborting\n";
-        return 1;
-    }
 
     Database db;
     db.setPath(path);
@@ -101,6 +95,8 @@ int main(int argc, char** argv)
 
     QObject::connect(&filewatcher, SIGNAL(indexFile(QString)),
                      &fileIndexer, SLOT(indexFile(QString)));
+    QObject::connect(&filewatcher, SIGNAL(indexXAttr(QString)),
+                     &fileIndexer, SLOT(indexXAttr(QString)));
     QObject::connect(&filewatcher, SIGNAL(installedWatches()),
                      &fileIndexer, SLOT(update()));
     QObject::connect(&filewatcher, SIGNAL(fileRemoved(int)),
