@@ -60,17 +60,7 @@ void MetadataMover::moveFileMetadata(const QString& from, const QString& to)
 void MetadataMover::removeFileMetadata(const QString& file)
 {
     Q_ASSERT(!file.isEmpty() && file != QLatin1String("/"));
-    removeFileMetadata(QStringList() << file);
-}
-
-
-void MetadataMover::removeFileMetadata(const QStringList& files)
-{
-    qDebug() << files;
-
-    Q_FOREACH (const QString& file, files) {
-        removeMetadata(file);
-    }
+    removeMetadata(file);
 }
 
 
@@ -99,11 +89,7 @@ void MetadataMover::removeMetadata(const QString& url)
 void MetadataMover::updateMetadata(const QString& from, const QString& to)
 {
     qDebug() << from << "->" << to;
-    if (from.isEmpty() || to.isEmpty()) {
-        qWarning() << "Paths Empty - File a bug" << from << to;
-        return;
-    }
-
+    Q_ASSERT(!from.isEmpty() && !to.isEmpty());
     Q_ASSERT(from[from.size()-1] != QLatin1Char('/'));
     Q_ASSERT(to[to.size()-1] != QLatin1Char('/'));
 
