@@ -31,6 +31,8 @@
 #include <QtTest>
 
 #include <xapian.h>
+#include <kfilemetadata/properties.h>
+#include <kfilemetadata/propertyinfo.h>
 
 
 using namespace Baloo;
@@ -180,6 +182,33 @@ void FileSearchStoreTest::testSimpleSearchString()
     m_store->close(qid);
 }
 
+void FileSearchStoreTest::testPropertyValueEqual()
+{
+    QString url1(QLatin1String("/home/t/a"));
+    uint id1 = insertUrl(url1);
+    insertText(id1, QLatin1String("This is sample text"));
+
+    QString url2(QLatin1String("/home/t/b"));
+    uint id2 = insertUrl(url2);
+    insertText(id2, QLatin1String("sample sample more sample but not text"));
+
+    Query q;
+    q.setTerm(Term(QString(), "Sample text", Baloo::Term::Equal));
+    q.addType(QLatin1String("File"));
+
+    int qid = m_store->exec(q);
+    QCOMPARE(qid, 1);
+    QVERIFY(m_store->next(qid));
+    QCOMPARE(m_store->id(qid), serialize("file", id1));
+    QCOMPARE(m_store->url(qid), QUrl::fromLocalFile(url1));
+
+    QVERIFY(!m_store->next(qid));
+    QVERIFY(m_store->id(qid).isEmpty());
+    QVERIFY(m_store->url(qid).isEmpty());
+
+    m_store->close(qid);
+}
+
 void FileSearchStoreTest::testIncludeDir()
 {
     QString url1(QLatin1String("/home/t/a"));
@@ -398,7 +427,111 @@ void FileSearchStoreTest::testFileNameSearch()
     QVERIFY(m_store->next(qid3));
     QCOMPARE(m_store->id(qid3), serialize("file", id2));
     QVERIFY(!m_store->next(qid3));
+
+    // Exact match
+    q.setTerm(Term("filename", "dork", Term::Equal));
+
+    int qid4 = m_store->exec(q);
+    QCOMPARE(qid4, 4);
+    QVERIFY(m_store->next(qid4));
+    QCOMPARE(m_store->id(qid4), serialize("file", id1));
+    QVERIFY(!m_store->next(qid4));
 }
 
+void FileSearchStoreTest::testSortingNone()
+{
+    insertText(1, QLatin1String("Power A"));
+    insertText(2, QLatin1String("Power Power B"));
+
+    Query q;
+    q.addType(QLatin1String("File"));
+    q.setSearchString("Power");
+
+    int qid;
+
+    // Auto sort - Based on frequency
+    qid = m_store->exec(q);
+    QCOMPARE(qid, 1);
+    QVERIFY(m_store->next(qid));
+    QCOMPARE(m_store->id(qid), serialize("file", 2));
+    QVERIFY(m_store->next(qid));
+    QCOMPARE(m_store->id(qid), serialize("file", 1));
+    QVERIFY(!m_store->next(qid));
+
+    // no sort
+    q.setSortingOption(Query::SortNone);
+
+    qid = m_store->exec(q);
+    QCOMPARE(qid, 2);
+    QVERIFY(m_store->next(qid));
+    QCOMPARE(m_store->id(qid), serialize("file", 1));
+    QVERIFY(m_store->next(qid));
+    QCOMPARE(m_store->id(qid), serialize("file", 2));
+    QVERIFY(!m_store->next(qid));
+}
+
+void FileSearchStoreTest::testInvalidProperties()
+{
+    Query q;
+    q.addType(QLatin1String("File"));
+    q.setTerm(Term("NoNExistingProperty", QVariant(1)));
+
+    int qid = m_store->exec(q);
+    QCOMPARE(qid, 0);
+    QVERIFY(!m_store->next(qid));
+}
+
+void FileSearchStoreTest::testModifiedProperty()
+{
+    QDateTime dt(QDate(2013, 12, 02), QTime(12, 2, 2));
+    insertExactText(1, dt.toString(Qt::ISODate), "DT_M");
+    insertExactText(2, QDateTime::currentDateTime().toString(Qt::ISODate), "DT_M");
+
+    Query q;
+    q.addType(QLatin1String("File"));
+    q.setTerm(Term(("modified"), dt.date(), Term::Equal));
+
+    int qid = m_store->exec(q);
+
+    QVERIFY(m_store->next(qid));
+    QCOMPARE(m_store->id(qid), serialize("file", 1));
+    QVERIFY(!m_store->next(qid));
+
+    q.setTerm(Term(("modified"), dt, Term::Equal));
+
+    qid = m_store->exec(q);
+
+    QVERIFY(m_store->next(qid));
+    QCOMPARE(m_store->id(qid), serialize("file", 1));
+    QVERIFY(!m_store->next(qid));
+}
+
+void FileSearchStoreTest::testDateTimeProperty()
+{
+    KFileMetaData::PropertyInfo propInfo(KFileMetaData::Property::CreationDate);
+    QString prefix = "X" + QString::number((int)propInfo.property());
+
+    QDateTime dt(QDate(2013, 12, 02), QTime(12, 2, 2));
+    insertExactText(1, dt.toString(Qt::ISODate), prefix);
+    insertExactText(2, QDateTime::currentDateTime().toString(Qt::ISODate), prefix);
+
+    Query q;
+    q.addType(QLatin1String("File"));
+    q.setTerm(Term(propInfo.name(), dt.date(), Term::Equal));
+
+    int qid = m_store->exec(q);
+
+    QVERIFY(m_store->next(qid));
+    QCOMPARE(m_store->id(qid), serialize("file", 1));
+    QVERIFY(!m_store->next(qid));
+
+    q.setTerm(Term((propInfo.name()), dt, Term::Equal));
+
+    qid = m_store->exec(q);
+
+    QVERIFY(m_store->next(qid));
+    QCOMPARE(m_store->id(qid), serialize("file", 1));
+    QVERIFY(!m_store->next(qid));
+}
 
 QTEST_MAIN(Baloo::FileSearchStoreTest)
