@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Baloo Project
- * Copyright (C) 2013  Vishesh Handa <me@vhanda.in>
+ * Copyright (C) 2013-2014 Vishesh Handa <vhanda@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,6 +26,8 @@
 #include "filemapping.h"
 #include "pathfilterpostingsource.h"
 #include "wildcardpostingsource.h"
+#include "xapianqueryparser.h"
+#include "xapiantermgenerator.h"
 
 #include <xapian.h>
 #include <QVector>
@@ -47,12 +49,12 @@ FileSearchStore::FileSearchStore(QObject* parent)
     const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/baloo/file/");
     setDbPath(path);
 
-    m_prefixes.insert(QLatin1String("filename"), "F");
-    m_prefixes.insert(QLatin1String("mimetype"), "M");
-    m_prefixes.insert(QLatin1String("rating"), "R");
-    m_prefixes.insert(QLatin1String("tag"), "TA");
-    m_prefixes.insert(QLatin1String("tags"), "TA");
-    m_prefixes.insert(QLatin1String("usercomment"), "C");
+    m_prefixes.insert(QStringLiteral("filename"), QStringLiteral("F"));
+    m_prefixes.insert(QStringLiteral("mimetype"), QStringLiteral("M"));
+    m_prefixes.insert(QStringLiteral("rating"), QStringLiteral("R"));
+    m_prefixes.insert(QStringLiteral("tag"), QStringLiteral("TA"));
+    m_prefixes.insert(QStringLiteral("tags"), QStringLiteral("TA"));
+    m_prefixes.insert(QStringLiteral("usercomment"), QStringLiteral("C"));
 }
 
 FileSearchStore::~FileSearchStore()
@@ -95,6 +97,23 @@ Xapian::Query FileSearchStore::convertTypes(const QStringList& types)
     return xapQ;
 }
 
+QString FileSearchStore::fetchPrefix(const QString& property) const
+{
+    auto it = m_prefixes.constFind(property.toLower());
+    if (it != m_prefixes.constEnd()) {
+        return it.value();
+    }
+    else {
+        KFileMetaData::PropertyInfo pi = KFileMetaData::PropertyInfo::fromName(property);
+        if (pi.property() == KFileMetaData::Property::Empty) {
+            qDebug() << "Property" << property << "not found";
+            return QString();
+        }
+        int propPrefix = static_cast<int>(pi.property());
+        return QLatin1Char('X') + QString::number(propPrefix);
+    }
+}
+
 Xapian::Query FileSearchStore::constructQuery(const QString& property, const QVariant& value,
                                               Term::Comparator com)
 {
@@ -102,6 +121,13 @@ Xapian::Query FileSearchStore::constructQuery(const QString& property, const QVa
     if (value.isNull())
         return Xapian::Query();
 
+    //
+    // Sanitize the values
+    //
+    if (value.type() == QVariant::Int && com == Term::Contains) {
+        com = Term::Equal;
+    }
+
     if (property.compare(QLatin1String("rating"), Qt::CaseInsensitive) == 0) {
         int val = value.toInt();
         if (val == 0)
@@ -139,64 +165,115 @@ Xapian::Query FileSearchStore::constructQuery(const QString& property, const QVa
         return Xapian::Query(&ws);
     }
 
+    if (property.compare(QLatin1String("modified"), Qt::CaseInsensitive) == 0) {
+        if (com == Term::Equal || com == Term::Contains) {
+            XapianQueryParser parser;
+            parser.setDatabase(xapianDb());
+
+            QString val;
+            if (value.type() == QVariant::Date) {
+                val = value.toDate().toString(Qt::ISODate);
+            } else if (value.type() == QVariant::DateTime) {
+                val = value.toDateTime().toString(Qt::ISODate);
+            }
+
+            return parser.expandWord(val, QStringLiteral("DT_M"));
+        }
+
+        if (com == Term::Greater || com == Term::GreaterEqual ||
+            com == Term::Less || com == Term::LessEqual)
+        {
+            qlonglong numVal = 0;
+            int slotNumber = 0;
+
+            if (value.type() == QVariant::DateTime) {
+                slotNumber = 0;
+                numVal = value.toDateTime().toTime_t();
+            }
+            else if (value.type() == QVariant::Date) {
+                slotNumber = 1;
+                numVal = value.toDate().toJulianDay();
+            }
+
+            if (com == Term::Greater) {
+                ++numVal;
+            }
+            if (com == Term::Less) {
+                --numVal;
+            }
+
+            if (com == Term::GreaterEqual || com == Term::Greater) {
+                return Xapian::Query(Xapian::Query::OP_VALUE_GE, slotNumber, QString::number(numVal).toStdString());
+            }
+            else if (com == Term::LessEqual || com == Term::Less) {
+                return Xapian::Query(Xapian::Query::OP_VALUE_LE, slotNumber, QString::number(numVal).toStdString());
+            }
+        }
+    }
+
+    if (value.type() == QVariant::Date || value.type() == QVariant::DateTime) {
+        if (com == Term::Equal || com == Term::Contains) {
+            XapianQueryParser parser;
+            parser.setDatabase(xapianDb());
+
+            QString val;
+            if (value.type() == QVariant::Date) {
+                val = value.toDate().toString(Qt::ISODate);
+            } else if (value.type() == QVariant::DateTime) {
+                val = value.toDateTime().toString(Qt::ISODate);
+            }
+
+            return parser.expandWord(val, fetchPrefix(property));
+        }
+        // FIXME: Should we expressly forbid other comparisons?
+    }
+
     if (com == Term::Contains) {
-        Xapian::QueryParser parser;
-        parser.set_database(*xapianDb());
+        XapianQueryParser parser;
+        parser.setDatabase(xapianDb());
 
-        std::string p;
-        QHash<QString, std::string>::const_iterator it = m_prefixes.constFind(property.toLower());
-        if (it != m_prefixes.constEnd()) {
-            p = it.value();
-        }
-        else {
-            KFileMetaData::PropertyInfo pi = KFileMetaData::PropertyInfo::fromName(property);
-            int propPrefix = static_cast<int>(pi.property());
-            p = QString(QLatin1Char('X') + QString::number(propPrefix)).toUtf8().constData();
+        QString prefix;
+        if (!property.isEmpty()) {
+            prefix = fetchPrefix(property);
+            if (prefix.isEmpty()) {
+                return Xapian::Query();
+            }
         }
 
-        const QByteArray arr = value.toString().toUtf8();
-        int flags = Xapian::QueryParser::FLAG_DEFAULT | Xapian::QueryParser::FLAG_PARTIAL;
-        return parser.parse_query(arr.constData(), flags, p);
+        return parser.parseQuery(value.toString(), prefix);
     }
 
-    if ((property.compare(QLatin1String("modified"), Qt::CaseInsensitive) == 0)
-        && (com == Term::Equal || com == Term::Greater ||
-            com == Term::GreaterEqual || com == Term::Less || com == Term::LessEqual))
-    {
-        qlonglong numVal = 0;
-        int slotNumber = 0;
+    if (com == Term::Equal) {
+        // We use the TermGenerator to normalize the words in the value and to
+        // split it into other words. If we split the words, we then add them as a
+        // phrase query.
+        QStringList terms = XapianTermGenerator::termList(value.toString());
 
-        if (value.type() == QVariant::DateTime) {
-            slotNumber = 0;
-            numVal = value.toDateTime().toTime_t();
-        }
-        else if (value.type() == QVariant::Date) {
-            slotNumber = 1;
-            numVal = value.toDate().toJulianDay();
+        QString prefix;
+        if (!property.isEmpty()) {
+            prefix = fetchPrefix(property);
+            if (prefix.isEmpty()) {
+                return Xapian::Query();
+            }
         }
 
-        if (com == Term::Greater) {
-            ++numVal;
-        }
-        if (com == Term::Less) {
-            --numVal;
+        QList<Xapian::Query> queries;
+        int position = 1;
+        for (const QString& term : terms) {
+            QByteArray arr = (prefix + term).toUtf8();
+            queries << Xapian::Query(arr.constData(), 1, position++);
         }
 
-        if (com == Term::GreaterEqual || com == Term::Greater) {
-            return Xapian::Query(Xapian::Query::OP_VALUE_GE, slotNumber, QString::number(numVal).toStdString());
-        }
-        else if (com == Term::LessEqual || com == Term::Less) {
-            return Xapian::Query(Xapian::Query::OP_VALUE_LE, slotNumber, QString::number(numVal).toStdString());
-        }
-        else if (com == Term::Equal) {
-            const Xapian::Query gtQuery(Xapian::Query::OP_VALUE_GE, slotNumber, QString::number(numVal).toStdString());
-            const Xapian::Query ltQuery(Xapian::Query::OP_VALUE_LE, slotNumber, QString::number(numVal).toStdString());
-            return Xapian::Query(Xapian::Query::OP_AND, gtQuery, ltQuery);
+        if (queries.isEmpty()) {
+            return Xapian::Query();
+        } else if (queries.size() == 1) {
+            return queries.first();
+        } else {
+            return Xapian::Query(Xapian::Query::OP_PHRASE, queries.begin(), queries.end());
         }
     }
 
-    const QByteArray arr = value.toString().toUtf8();
-    return Xapian::Query(arr.constData());
+    return Xapian::Query();
 }
 
 Xapian::Query FileSearchStore::constructFilterQuery(int year, int month, int day)
