@@ -85,6 +85,9 @@ void XapianDatabase::replaceDocument(uint id, const Xapian::Document& doc)
 
 void XapianDatabase::deleteDocument(uint id)
 {
+    if (id == 0)
+        return;
+
     if (m_writeOnly) {
         try {
             m_wDb.delete_document(id);
@@ -96,6 +99,11 @@ void XapianDatabase::deleteDocument(uint id)
     m_docsToRemove << id;
 }
 
+bool XapianDatabase::haveChanges() const
+{
+    return !m_docsToAdd.isEmpty() || !m_docsToRemove.isEmpty();
+}
+
 void XapianDatabase::commit()
 {
     if (m_writeOnly) {
@@ -108,7 +116,7 @@ void XapianDatabase::commit()
         return;
     }
 
-    if (m_docsToAdd.isEmpty() && m_docsToRemove.isEmpty()) {
+    if (!haveChanges()) {
         return;
     }
 
