@@ -25,7 +25,7 @@
 #include <QString>
 
 #include "xapian_export.h"
-#include "termgenerator.h"
+#include "xapiantermgenerator.h"
 
 namespace Baloo {
 
@@ -52,10 +52,15 @@ public:
 
     QString fetchTermStartsWith(const QByteArray& term);
 
-    void removeTermStartsWith(const QByteArray& prefix);
+    /**
+     * Remove all the terms which start with the prefix \p prefix
+     *
+     * \return true if the document was modified
+     */
+    bool removeTermStartsWith(const QByteArray& prefix);
 private:
     Xapian::Document m_doc;
-    TermGenerator m_termGen;
+    XapianTermGenerator m_termGen;
 };
 }
 
